Preferences/ProgramsDialog.py

branch
pypi
changeset 6782
390a45748883
parent 6672
2af01e538c57
diff -r 9ede19ddfa98 -r 390a45748883 Preferences/ProgramsDialog.py
--- a/Preferences/ProgramsDialog.py	Sun Feb 17 18:33:42 2019 +0100
+++ b/Preferences/ProgramsDialog.py	Sun Feb 17 19:19:30 2019 +0100
@@ -224,8 +224,16 @@
         self.__createProgramEntry(
             self.tr("conda Manager"), exe, '--version', 'conda', -1)
         
-        # 6. do the CORBA and Protobuf programs
-        # 6a. omniORB
+        # 6. do the pip program(s)
+        virtualenvManager = e5App().getObject("VirtualEnvManager")
+        for venvName in virtualenvManager.getVirtualenvNames():
+            interpreter = virtualenvManager.getVirtualenvInterpreter(venvName)
+            self.__createProgramEntry(
+                self.tr("PyPI Package Management"), interpreter, '--version',
+                'pip', 1, exeModule=["-m", "pip"])
+        
+        # 7. do the CORBA and Protobuf programs
+        # 7a. omniORB
         exe = Preferences.getCorba("omniidl")
         if not exe:
             exe = "omniidl"
@@ -233,7 +241,7 @@
                 exe += ".exe"
         self.__createProgramEntry(
             self.tr("CORBA IDL Compiler"), exe, '-V', 'omniidl', -1)
-        # 6b. protobuf
+        # 7b. protobuf
         exe = Preferences.getProtobuf("protoc")
         if not exe:
             exe = "protoc"
@@ -241,7 +249,7 @@
                 exe += ".exe"
         self.__createProgramEntry(
             self.tr("Protobuf Compiler"), exe, '--version', 'libprotoc', -1)
-        # 6c. grpc
+        # 7c. grpc
         exe = Preferences.getProtobuf("grpcPython")
         if not exe:
             exe = sys.executable
@@ -249,7 +257,7 @@
             self.tr("gRPC Compiler"), exe, '--version', 'libprotoc', -1,
             exeModule=['-m', 'grpc_tools.protoc'])
         
-        # 7. do the spell checking entry
+        # 8. do the spell checking entry
         try:
             import enchant
             try:
@@ -266,7 +274,7 @@
         self.__createEntry(
             self.tr("Spell Checker - PyEnchant"), text, version)
         
-        # 8. do the pygments entry
+        # 9. do the pygments entry
         try:
             import pygments
             try:
@@ -283,7 +291,7 @@
         self.__createEntry(
             self.tr("Source Highlighter - Pygments"), text, version)
         
-        # 9. do the plugin related programs
+        # 10. do the plugin related programs
         pm = e5App().getObject("PluginManager")
         for info in pm.getPluginExeDisplayData():
             if info["programEntry"]:

eric ide

mercurial